Date: 01 4, 2002 2:58:17 AM

# Code Zone

The Code Zone is reserved for regions of NLP++ code that are independent of rule matching.

## Code Region

Currently, the only region implemented within the Code Zone is the CODE Region, which is delimited by @CODE and (optionally) by @@CODE, and operates before any rule matching is executed for the current pass file.

A pass file may consist entirely of a Code Region.

## See Also

CODE Region

CODE Action